OpenSeesPyMac

Pip package for OpenSeesPy for the Mac OS. Supports OSX 10.12 and up.

Requires Python 3.8 or higher installed from <https://www.python.org/downloads/> 

Mac version maintained by:

Dr. Stevan Gavrilovic <gavrilovic@berkeley.edu>,
Structural and Earthquake Engineering,
University of California, Berkeley

OpenSeesPy Developer:

Minjie Zhu <zhum@oregonstate.edu>

Faculty Research Assistant,
Civil and Construction Engineering,
Oregon State University

OpenSeesPy Documentation <https://openseespydoc.readthedocs.io/en/latest/index.html>

